@@ -1,22 +1,28 @@
 package Path::Dispatcher::Dispatch;
-use Moose;
-use MooseX::AttributeHelpers;
+use Any::Moose;
 
 use Path::Dispatcher::Match;
 
 has _matches => (
-    metaclass => 'Collection::Array',
     is        => 'rw',
-    isa       => 'ArrayRef[Path::Dispatcher::Match]',
+    isa       => 'ArrayRef',
     default   => sub { [] },
-    provides  => {
-        push     => 'add_match',
-        elements => 'matches',
-        count    => 'has_match',
-        first    => 'first_match',
-    },
 );
 
+sub add_match {
+    my $self = shift;
+
+    $_->isa('Path::Dispatcher::Match')
+        or confess "$_ is not a Path::Dispatcher::Match"
+            for @_;
+
+    push @{ $self->{matches} }, @_;
+}
+
+sub matches     { @{ shift->{matches} } }
+sub has_match   { scalar @{ shift->{matches} } }
+sub first_match { shift->{matches}[0] }
+
 # aliases
 __PACKAGE__->meta->add_method(add_matches => __PACKAGE__->can('add_match'));
 __PACKAGE__->meta->add_method(has_matches => __PACKAGE__->can('has_match'));
@@ -53,7 +59,7 @@ sub run {
 }
 
 __PACKAGE__->meta->make_immutable;
-no Moose;
+no Any::Moose;
 
 1;
 
